

/*This file was written by Anne Case - Princeton University,  the only modificataions 
are to path names and some variable names - to match the distributed copy*/

#delimit;

set more off;
cap log close;
cap drop _all;
cap prog drop _all;

log using "c:\case email\oincome.log", replace;


/* making a file of earned and unearned income and age  */;
/* This file has two parts.
   In Part 1, we sum up all of the types of
   incomes recorded for this person -- regular job, self employed etc.
   in the older adult module using files on jobs.

   In Part 2, we add in the information on the household module's
   respondent, who may not have filled out a older adult module,
   because that information could be taken from the household income module */;


/* here I use Matthew's clean files */;

/**************************************************************/;
/****************** Part 1 ************************************/;
/**************************************************************/;

use "C:\Distribute\Confidential\Stata\older\olderregjob_01d.dta", clear;
keep UniqueID PCode Regular3 OddJobSa SelfJobS;
sum Regular3, det;
sum OddJobSa, det;
sum SelfJobS, det;

sort UniqueID PCode;

replace Regular3 = 0 if Regular3==.;
replace OddJobSa = 0 if OddJobSa==.;
replace SelfJobS = 0 if SelfJobS==.;

save "c:\case email\oincome.dta", replace;

drop _all;

use "C:\Distribute\Confidential\Stata\older\olderreceive_01d.dta", clear;

/* be careful here - we don't want to count gifts from someone in the hhold in
   our measurement of hhold income but we'll still want to keep track
   of it */;

  gen giftinm = 0;
  gen giftoutm = 0;
  label var giftinm "resources received from other hhold members, monthly";
  label var giftoutm "resources received from outside the hhold, monthly";

  replace giftoutm = MoneyPas/12 if Househo1==2 & MoneyPas!=.;
  replace giftinm  = MoneyPas/12 if Househo1==1 & MoneyPas!=.;

  egen  giftin = sum(giftinm),  by(UniqueID PCode);
  egen  giftout= sum(giftoutm), by(UniqueID PCode);

label var giftin "resources received from other hhold members, monthly";
label var giftout "resources received from outside the hhold, monthly";

  sort UniqueID PCode;
  qui by UniqueID PCode: keep if _n==1;
  keep UniqueID PCode giftin giftout;

merge UniqueID PCode using "c:\case email\oincome.dta";
  tab _m;
  drop _m;
  replace giftin = 0 if giftin ==.;
  replace giftout = 0 if giftout ==.;
sort UniqueID PCode;
save "c:\case email\oincome.dta", replace;


use "C:\Distribute\Confidential\Stata\older\olderpension_01d.dta", clear;
keep UniqueID PCode StateOl2 Disabil2 Veteran2;

egen unearno = rsum(StateOl2 Disabil2 Veteran2);
replace unearno = 0 if unearno ==.;

sort UniqueID PCode;
merge UniqueID PCode using "c:\case email\oincome.dta";
replace StateOl2 = 0 if StateOl2 ==.;
replace Disabil2 = 0 if Disabil2 ==.;
replace Veteran2 = 0 if Veteran2 ==.;
replace unearno  = 0 if unearno  ==.;
  replace giftin = 0 if giftin ==.;
  replace giftout = 0 if giftout ==.;
replace unearno = unearno + giftout;
label var unearno "rsum(StateOl2 Disabil2 Veteran2) + giftout";


sum;
tab _m;
drop _m;

gen Earningo = Regular3 + OddJobSa + SelfJobS;
label var Earningo "Regular3 + OddJobSa + SelfJobS";
sort UniqueID PCode;
save "c:\case email\oincome.dta",replace;


/**************************************************************/;
/****************** Part 2 ************************************/;
/**************************************************************/;


/* now see if we need to add in anything from hhold module
   for respondents who might have only filled in hhold module, and
   for this reason didn't fill out the older adult module */;


use "C:\Distribute\Confidential\Stata\householdmod\householdmod_01d.dta", clear;

keep UniqueID Code;
gen PCode = real(Code);
sort UniqueID PCode;
save temp,replace;

use "C:\Distribute\Confidential\Stata\householdmod\householdinc_02d.dta", clear;

sort UniqueID PCode;
merge UniqueID PCode using temp;
tab _m;
drop if _m !=3;
/*so this should be just the respondent talking about the respondent's income*/;

  egen unearn1 = rsum(OldAgePe-Retireme);
  egen unearn2 = rsum(Savings-GoodsOut);
  replace Otherinc = 0 if Otherinc ==.;
  gen unearnR = unearn1 + unearn2 + Otherinc;

/* check for outliers */;

  sum  OldAgePe, det;
  sum  Veterans, det;
  sum  Disabili, det;
  sum  Empl_old, det;
  sum  Empl_com, det;
  sum  UIF     , det;
  sum  StateGra, det;
  sum  PrivateG, det;
  sum  NewChild, det;
  sum  FosterCa, det;
  sum  CareGran, det;
  sum  Retireme, det;
  sum  Earnings, det;

/* a couple of these I'm going to change because they are too large
   to be credible */;

replace Earnings = 1400 if Earnings ==1400000;
replace Earnings = 10833 if Earnings==108333;
replace Earnings = 0 if Earnings ==.;
  sum  Savings , det;
  sum  Religiou, det;
  sum  Property, det;
  sum  MoneyOut, det;
  sum  GoodsOut, det;
  sum  MoneyIns, det;
  sum  GoodsIns, det;
  sum  Otherinc, det;


  keep UniqueID PCode Earnings unearnR;
  sort UniqueID PCode;
/* get the age of this person to assign them to younger or older income module */;

merge UniqueID PCode using c:\distribute\confidential\stata\hhmems.dta;
  keep if _m==3;

  keep UniqueID PCode Earnings unearnR Age;
  sort UniqueID PCode;
  sum;
  label data "Respondent's answers on his/her income, hhold mod";
save "c:\case email\Rincome.dta",replace;


use  "c:\case email\oincome.dta",replace;
  sort UniqueID PCode;
merge UniqueID PCode using "c:\case email\Rincome.dta";
  tab _m;

/*********************************************************************************************/;
/* so here _merge==1 was someone in pincome, but not respondent in hhold mod
           _merge==2 was Respondent in hhold mod, who did not show up in younger income mods
           _merge==3 was both
      Earningp will be equal to missing for people with _m==2
      Earningp will be equal to zero (possibly) if hhold Respondent is this person */;
/*********************************************************************************************/;


  replace Earningo = Earnings if Earningo ==. & Earnings!=.;
  replace Earningo = Earnings if Earningo ==0 & Earnings!=0 & Earnings!=.;

  replace unearno = unearnR if unearno ==. & unearnR!=.;
  replace unearno = unearnR if unearno ==0 & unearnR!=0 & unearnR!=.;

  gen totinco = Earningo + unearno;
  label var totinco "unearned + Earned,best info o.adult & hhold module";

  tab _m if Age>=55 & Age!=.;

keep if ( (_m==1)|(_m==2 & (Age>=55 & Age!=.)) | (_m==3) );
drop Age Earnings unearnR _m;

d;
  sum totinco,det;
  sum Earningo, det;
  sum unearno, det;
sum;
sort UniqueID PCode;
label data "Older Income from household and older adult modules";

save "c:\case email\oincome.dta",replace;

log close;
/*translate oincome.smcl oincome.log, replace*/;
