

/*This file was written by Anne Case - Princeton University,  the only modificataions 
are to path names and some variable names - to match the distributed copy*/

#delimit;
set more off;
cap log close;
cap drop _all;
cap prog drop _all;

log using "c:\case email\yincome.log", replace;


/* making a file of earned and unearned income and age  */;
/* This file has two parts.
   In Part 1, we sum up all of the types of
   incomes recorded for this person -- regular job, self employed etc.
   in the younger adult module using files on jobs.

   In Part 2, we add in the information on the household module's
   respondent, who may not have filled out a younger adult module,
   because that information could be taken from the household income module */;


/* here I use Matthew's cleaned files */;


/**************************************************************/;
/****************** Part 1 ************************************/;
/**************************************************************/;


use c:\distribute\confidential\stata\younger\youngerregularjob_03d.dta,replace;
keep  UniqueID PCode  SalaryPe;
rename SalaryPe earnregl;
sum earnregl,det;
sort UniqueID PCode;
save "c:\case email\yincome",replace;


use c:\distribute\confidential\stata\younger\youngeroddjo_03d.dta,replace;
keep UniqueID PCode SalaryPe;

rename SalaryPe earnoddj;
sum earnoddj, det;
sort UniqueID PCode;
merge UniqueID PCode using "c:\case email\yincome";
tab _m;
drop _m;
replace earnregl = 0 if earnregl ==.;
replace earnoddj = 0 if earnoddj ==.;
sort UniqueID PCode;

save "c:\case email\yincome",replace;

drop _all;

use c:\distribute\confidential\stata\younger\youngerselfemp_03d.dta,replace;
keep UniqueID PCode SalaryPe;

rename SalaryPe earnself;
/* checking for outliers */;
summ earnself, det;
/* one outlier we'll trim */;
replace earnself = 1400 if earnself ==1400000;

sort UniqueID PCode;
merge UniqueID PCode using "c:\case email\yincome";
tab _m;
drop _m;

replace earnregl = 0 if earnregl ==.;
replace earnoddj = 0 if earnoddj ==.;
replace earnself = 0 if earnself ==.;

sort UniqueID PCode;
save "c:\case email\yincome",replace;

drop _all;

use c:\distribute\confidential\stata\younger\youngerreceivemoney_03d.dta,replace;
/* be careful here - we don't want to count gifts from someone in the hhold in
   our measurement of hhold income but we'll still want to keep track
   of it */;
gen giftinm = 0;
gen giftoutm = 0;
label var giftinm "resources received from other hhold members, monthly";
label var giftoutm "resources received from outside the hhold, monthly";

replace giftoutm = AmountMo/12 if Househo1==2 & AmountMo!=.;
replace giftinm  = AmountMo/12 if Househo1==1 & AmountMo!=.;

egen  giftin = sum(giftinm),  by(UniqueID PCode);
egen  giftout= sum(giftoutm), by(UniqueID PCode);

sort UniqueID PCode;
qui by UniqueID PCode: keep if _n==1;
keep UniqueID PCode giftin giftout;

label var giftin  "tot amount individual receives from those in hhold";
label var giftout "tot amount individual receives from outside hhold";
sort UniqueID PCode;

merge UniqueID PCode using "c:\case email\yincome";
drop _m;

replace earnregl = 0 if earnregl ==.;
replace earnoddj = 0 if earnoddj ==.;
replace earnself = 0 if earnself ==.;
replace giftin   = 0 if giftin   ==.;
replace giftout  = 0 if giftout  ==.;

sort UniqueID PCode;
save "c:\case email\yincome",replace;



use c:\distribute\confidential\stata\younger\youngermod_03d.dta,replace;
keep UniqueID PCode Veterans-Other_h7;
egen unearnp  = rsum(Veterans-Other_h7);
sort UniqueID PCode;
merge UniqueID PCode using "c:\case email\yincome";
tab _m;
drop _m;
replace earnregl= 0 if earnregl ==.;
replace earnoddj= 0 if earnoddj ==.;
replace earnself= 0 if earnself ==.;
replace giftin  = 0 if giftin   ==.;
replace giftout = 0 if giftout  ==.;
replace unearnp = 0 if unearnp  ==.;
replace unearnp = unearnp + giftout;

gen Earningp = earnregl + earnoddj + earnself;
label var Earningp "earned income, younger adults";
label var unearnp "unearned income, younger adults";

sort UniqueID PCode;
qui by UniqueID PCode: gen nper=_N;
tab nper;
drop nper;
sort UniqueID PCode;
save "c:\case email\yincome",replace;

/**************************************************************/;
/****************** Part 2 ************************************/;
/**************************************************************/;


/* now see if we need to add in anything from hhold module
   for respondents who might have only filled in hhold module, and
   for this reason didn't fill out the younger adult module */;


use c:\distribute\confidential\stata\householdmod\householdmod_01d.dta;

keep UniqueID Code;
gen PCode = real(Code);
sort UniqueID PCode;
qui by UniqueID PCode: gen nper=_N;
tab nper;
drop nper;
sort UniqueID PCode;
save temp,replace;

use c:\distribute\confidential\stata\householdmod\householdinc_02d.dta;
sort UniqueID PCode;
qui by UniqueID PCode: gen nper = _N;
/* one person is listed twice, but has income only once */;
sum if nper==2;
drop nper;
qui by UniqueID PCode: keep if _n==1;

sort UniqueID PCode;
merge UniqueID PCode using temp;
tab _m;
drop if _m !=3;

sort UniqueID PCode;
qui by UniqueID PCode: gen nper=_N;
tab nper;
drop nper;

/*so this should be just the respondent talking about the respondent's income*/;

  egen unearn1 = rsum(OldAgePe-Retireme);
  egen unearn2 = rsum(Savings-GoodsOut);
  replace Otherinc = 0 if Otherinc ==.;
  gen unearnR = unearn1 + unearn2 + Otherinc;

/* check for outliers */;

  sum  OldAgePe, det;
  sum  Veterans, det;
  sum  Disabili, det;
  sum  Empl_old, det;
  sum  Empl_com, det;
  sum  UIF     , det;
  sum  StateGra, det;
  sum  PrivateG, det;
  sum  NewChild, det;
  sum  FosterCa, det;
  sum  CareGran, det;
  sum  Retireme, det;
  sum  Earnings, det;

/* a couple of these I'm going to change because they are too large
   to be credible */;

replace Earnings = 1400 if Earnings ==1400000;
replace Earnings = 10833 if Earnings==108333;
replace Earnings = 0 if Earnings ==.;
  sum  Savings , det;
  sum  Religiou, det;
  sum  Property, det;
  sum  MoneyOut, det;
  sum  GoodsOut, det;
  sum  MoneyIns, det;
  sum  GoodsIns, det;
  sum  Otherinc, det;


  keep UniqueID PCode Earnings unearnR;
  sort UniqueID PCode;
/* get the age of this person to assign them to younger or older income module */;

merge UniqueID PCode using c:\distribute\confidential\stata\hhmems.dta;
  keep if _m==3;

sort UniqueID PCode;

  keep UniqueID PCode Earnings unearnR Age;
  sort UniqueID PCode;
  sum;
  label data "Respondent's answers on his/her income, hhold mod";
save "c:\case email\Rincome",replace;


use  "c:\case email\yincome";
  sort UniqueID PCode;
merge UniqueID PCode using "c:\case email\Rincome";
  tab _m;

/*********************************************************************************************/;
/* so here _merge==1 was someone in yincome, but not respondent in hhold mod
           _merge==2 was Respondent in hhold mod, who did not show up in younger income mods
           _merge==3 was both
      Earningp will be equal to missing for people with _m==2
      Earningp will be equal to zero (possibly) if hhold Respondent is this person */;
/*********************************************************************************************/;


  replace Earningp = Earnings if Earningp ==. & Earnings!=.;
  replace Earningp = Earnings if Earningp ==0 & Earnings!=0 & Earnings!=.;

  replace unearnp = unearnR if unearnp ==. & unearnR!=.;
  replace unearnp = unearnR if unearnp ==0 & unearnR!=0 & unearnR!=.;

  gen totincp = Earningp + unearnp;
  label var totincp "unearned + Earned,best info y.adult & hhold module";

  tab _m if Age>=18 & Age<=54;

keep if ( (_m==1)|(_m==2 & (Age>=18 & Age<=54)) | (_m==3) );
drop Age Earnings unearnR _m;

d;
  sum totincp,det;
  sum Earningp, det;
  sum unearnp, det;
sum;
sort UniqueID PCode;
save "c:\case email\yincome",replace;

log close;
